/******************************************************************************
 * Lemonade JS
 * https://lemonadejs.com
 *
 * ----
 *
 * Utility
 *
 *  Common operations
 *
 *****************************************************************************/

function Utility() {}

/**
 * Dependencies
 */
var exec = require('child_process').exec;

/**
 * Current unixtime
 * @param {date|string} date
 * @return {number}
 */
Utility.prototype.time = function(date) {
    return Math.round(this.microtime(date) / 1000);
};

/**
 * Current microtime
 * @param {date|string} date
 * @return {number}
 */
Utility.prototype.microtime = function(date) {
    if (date instanceof Date) {
        return date.getTime();
    } else if (typeof date === 'string') {
        return new Date(date).getTime();
    } else {
        return new Date().getTime();
    }
};

/**
 * Format date
 * @param {Date|string} date
 * @param {string} format
 * @return {string}
 */
Utility.prototype.date = function(date, format) {

    if (typeof date === 'string') {
        date = new Date(date);
    } else if (!(date instanceof Date)) {
        date = new Date();
    }

    var  day    = date.getDate()
        ,month  = date.getMonth()
        ,year   = date.getFullYear()
        ,yr     = year.toString().substring(2,4)
        ,min    = date.getMinutes()
        ,hour   = date.getHours()
        ,sec    = date.getSeconds();

    format = format.replace('Y', year);
    format = format.replace('y', yr);
    format = format.replace('d', day);
    format = format.replace('m', month);
    format = format.replace('h', hour);
    format = format.replace('i', min);
    format = format.replace('s', sec);

    return format;
};

/**
 * Used to store if the console can handle colours
 */
Utility.prototype._ansicheck;

/**
 * Add some colors to our console output
 * @param {string} color
 * @param {string} message
 * @return {string}
 */
Utility.prototype.ansi = function(color, message) {
    if (typeof this.ansicheck === 'undefined') {
        exec('tput colors', function(err, stdout, stderr) {
            if (stdout>0) {
                this.ansicheck = true;
            } else {
                this.ansicheck = false;
            }
        }.bind(this));
    }
    if (this.ansicheck !== false) {
        var code, bold = '\033[1m', reset = '\033[0m';
        switch (color) {
            case 'green'  : code = '\033[32m'; break;
            case 'yellow' : code = '\033[33m'; break;
            case 'red'    : code = '\033[31m'; break;
            case 'blue'   : code = '\033[34m'; break;
        }
        return bold + code + message + reset;
    }
    return message;
};

/**
 * Export
 */
exports = module.exports = Utility;